package com.ruoyi.web.controller.ehs;

import java.util.List;
import java.util.Arrays;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.ehsNoticeMessage.domain.EhsNoticeMessage;
import com.ruoyi.ehsNoticeMessage.service.IEhsNoticeMessageService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.ehsMyMessage.domain.EhsMyMessage;
import com.ruoyi.ehsMyMessage.service.IEhsMyMessageService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 我的的消息Controller
 *
 * @author ruoyi
 * @date 2024-01-16
 */
@Api(tags="我的的消息管理")
@RestController
@RequestMapping("/ehsMyMessage/ehsMyMessage")
public class EhsMyMessageController extends BaseController
{
    @Autowired
    private IEhsMyMessageService ehsMyMessageService;
	@Autowired
	private IEhsNoticeMessageService ehsNoticeMessageService;
/**
 * 查询我的的消息列表
 */
//@PreAuthorize("@ss.hasPermi('ehsMyMessage:ehsMyMessage:list')")
@GetMapping("/list")
	public TableDataInfo list(EhsMyMessage ehsMyMessage)
	{
		startPage();
		List<EhsMyMessage> list = ehsMyMessageService.selectEhsMyMessageList(ehsMyMessage);
		return getDataTable(list);
	}

	/**
	 * 导出我的的消息列表
	 */
	//@PreAuthorize("@ss.hasPermi('ehsMyMessage:ehsMyMessage:export')")
	@Log(title = "我的的消息", businessType = BusinessType.EXPORT)
	@PostMapping("/export")
	public void export(HttpServletResponse response, EhsMyMessage ehsMyMessage)
	{
		List<EhsMyMessage> list = ehsMyMessageService.selectEhsMyMessageList(ehsMyMessage);
		ExcelUtil<EhsMyMessage> util = new ExcelUtil<EhsMyMessage>(EhsMyMessage.class);
		util.exportExcel(response, list, "我的的消息数据");
	}

	/**
	 * 获取我的的消息详细信息
	 */
	//@PreAuthorize("@ss.hasPermi('ehsMyMessage:ehsMyMessage:query')")
	@GetMapping(value = "/{myMessageId}")
	public AjaxResult getInfo(@PathVariable("myMessageId") Long myMessageId)
	{
		return success(ehsMyMessageService.selectEhsMyMessageByMyMessageId(myMessageId));
	}

    /**
     * 新增我的的消息
     */
    @ApiOperation("新增我的的消息")
    //@PreAuthorize("@ss.hasPermi('ehsMyMessage:ehsMyMessage:add')")
    @Log(title = "我的的消息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody EhsMyMessage ehsMyMessage)
    {
        return toAjax(ehsMyMessageService.save(ehsMyMessage));
    }

    /**
     * 修改我的的消息
     */
    @ApiOperation("修改我的的消息")
    //@PreAuthorize("@ss.hasPermi('ehsMyMessage:ehsMyMessage:edit')")
    @Log(title = "我的的消息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody EhsMyMessage ehsMyMessage)
    {
        return toAjax(ehsMyMessageService.updateById(ehsMyMessage));
    }

    /**
     * 删除我的的消息
     */
    @ApiOperation("删除我的的消息")
    //@PreAuthorize("@ss.hasPermi('ehsMyMessage:ehsMyMessage:remove')")
    @Log(title = "我的的消息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{myMessageIds}")
    public AjaxResult remove(@PathVariable Long[] myMessageIds)
    {
        return toAjax(ehsMyMessageService.removeByIds(Arrays.asList(myMessageIds)));
    }
	@GetMapping("/getUnread")
	public AjaxResult getUnread()
	{
		AjaxResult ajr = new AjaxResult();
		EhsMyMessage ehsMyMessage = new EhsMyMessage();
		ehsMyMessage.setMyMessageType("0");
		ehsMyMessage.setMyUserId(SecurityUtils.getUserId());
		EhsMyMessage msg = ehsMyMessageService.selectEhsMyMessageByMyMessageMax(ehsMyMessage);
		if(msg == null){
			ajr.put("msgHD","0");
		}else{
			if(msg.getMyMessageState().equals("N"))
				ajr.put("msgHD","1");
			else
				ajr.put("msgHD","0");
		}

		//分析是否有本人的未读消息通知
		//消息通知的每一记录，我的消息都应该有一条记录，如果没有，说明未读，并向我的消息插入一条记录，并设置为未读
		//消息通知模块点击阅读按钮后，需要同时修改我的消息的已读标志
		//统计我的消息类型=1的所有未读数量。
		EhsMyMessage myMsg = new EhsMyMessage();
		myMsg.setNoticeDeptId(SecurityUtils.getDeptId());
		myMsg.setNoticeStatus("1");
		myMsg.setNoticeMesgType(1L);
		myMsg.setMyMessageType("1");
		myMsg.setMyUserId(SecurityUtils.getUserId());
		List<EhsMyMessage> list = ehsMyMessageService.selectUnReadNotice(myMsg);
		if(!list.isEmpty()){
			for(EhsMyMessage emsg :list){
				EhsMyMessage msgNew = new EhsMyMessage();
				msgNew.setMyMessageKey(emsg.getMyMessageId().toString());
				ehsMyMessageService.saveMyMessage(msgNew);
			}
		}
		EhsMyMessage msgQuery = new EhsMyMessage();
		msgQuery.setMyMessageType("1");
		msgQuery.setMyMessageState("N");
		msgQuery.setMyUserId(SecurityUtils.getUserId());
		Long msgCount = ehsMyMessageService.msgCount(msgQuery);
		ajr.put("msg",msgCount.toString());
		return  ajr;
	}
}
